@@ -11,7 +11,8 @@ class AbstractClient(ABC):
     def __init__(self, tenant: str, username: str, password: str, env: EnvType) -> None:
         self.tenant = tenant
         self.env = env
-        self.token, self.refresh_token, self.x_api_key = KeyCloakAPI().authenticate(tenant, username, password)
+        self.org_id = 'sf_plus_' + str(tenant)
+        self.token, self.refresh_token, self.x_api_key = KeyCloakAPI(env).authenticate(tenant, username, password)
         logging.info("Super class is initialized")
     def get_auth(self) -> str:
         return self.token
